@@ -1,5 +1,5 @@
 "coef.ltm" <-
-function (object, standardized = FALSE, prob = FALSE, ...) {
+function (object, standardized = FALSE, prob = FALSE, order = FALSE, ...) {
     if (!inherits(object, "ltm"))
         stop("Use only with 'ltm' objects.\n")
     cof <- object$coef
@@ -30,6 +30,8 @@ function (object, standardized = FALSE, prob = FALSE, ...) {
     }
     if (prob)
         cof <- cbind(cof, "P(x=1|z=0)" = plogis(cof[, 1]))
+    if (order)
+        cof <- cof[order(cof[, 1]), ]
     round(cof, 3)
 }
 
